summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/catalogmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/catalogmanager.h')
-rw-r--r--kbabel/catalogmanager/catalogmanager.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kbabel/catalogmanager/catalogmanager.h b/kbabel/catalogmanager/catalogmanager.h
index d7cd467e..8a0fe6fd 100644
--- a/kbabel/catalogmanager/catalogmanager.h
+++ b/kbabel/catalogmanager/catalogmanager.h
@@ -57,7 +57,7 @@ class TQPixmap;
class TQPopupMenu;
class TQTimer;
class KProgress;
-class KAction;
+class TDEAction;
class TDEConfig;
class FindInFilesDialog;
@@ -67,7 +67,7 @@ namespace KBabel
class ProjectDialog;
}
-class CatalogManager : public KMainWindow
+class CatalogManager : public TDEMainWindow
{
Q_OBJECT
@@ -149,7 +149,7 @@ private slots:
/**
* calls @ref KBabel::open where as preferred windos _preferredWindow
* is used. If this is deleted meanwhile, the first window in
* @ref KMainWindow::memberList is used.
*/
void openFile(TQString filename,TQString package);
void openFile(TQString filename,TQString package, int msgid);
@@ -157,7 +157,7 @@ private slots:
/**
* calls @ref KBabel::openTemplate where as preferred windos _preferredWindow
* is used. If this is deleted meanwhile, the first window in
* @ref KMainWindow::memberList is used.
*/
void openTemplate(TQString openFilename,TQString saveFileName,TQString package);
void openTemplateInNewWindow(TQString openFilename,TQString saveFileName,TQString package);
@@ -149,7 +149,7 @@ private slots:
* calls @ref KBabel::open where as preferred windos _preferredWindow
* is used. If this is deleted meanwhile, the first window in
- * @ref KMainWindow::memberList is used.
+ * @ref TDEMainWindow::memberList is used.
*/
void openFile(TQString filename,TQString package);
@@ -157,7 +157,7 @@ private slots:
* calls @ref KBabel::openTemplate where as preferred windos _preferredWindow
* is used. If this is deleted meanwhile, the first window in
- * @ref KMainWindow::memberList is used.
+ * @ref TDEMainWindow::memberList is used.
*/
void openTemplate(TQString openFilename,TQString saveFileName,TQString package);